#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: models.py 11405 2019-03-27 05:20:03Z Lavender $
#
# Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License, 
# you may not use this file except in compliance with the License. 
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and 
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2019-03-27 14:20:03 +0900 (週三, 27 三月 2019) $
# $Revision: 11405 $ 

from django.apps import AppConfig

from django.utils.translation import ugettext_lazy as _

class FacebookConfig(AppConfig):
    name = 'Zephyrus.facebook'
    verbose_name = _("Facebook")